@@ -656,6 +656,15 @@ def populate_aws_snapshot(snapshot, container=None):
                                         config_value(DATABASE, DBNAME), 
                                         [('snapshotId', pymongo.ASCENDING),
                                         ('timestamp', pymongo.DESCENDING)])
+
+                                    create_indexes(
+                                        data['collection'],
+                                        config_value(DATABASE, DBNAME), 
+                                        [
+                                            ('_id', pymongo.DESCENDING),
+                                            ('timestamp', pymongo.DESCENDING),
+                                            ('snapshotId', pymongo.ASCENDING)
+                                        ])
                                 check_key = is_check_keys_required(data)
                                 insert_one_document(data, data['collection'], dbname, check_key)
                             else:
